@@ -52,7 +52,11 @@ class Client(object):
                 if param is not None:
                     payload["param"] = param
 
-                data = json.loads(self._fetch(self._get_api_root(method), json.dumps(payload)))
+                payload = json.dumps(
+                    payload, ensure_ascii=False).encode("utf-8")
+
+                data = json.loads(self._fetch(
+                    self._get_api_root(method), payload))
                 if type(data) != dict:
                     if self.logger:
                         self.logger.error("Got %s instead of a dict: %s" % (type(data), data))
